PaymentIntentData class

Constructors

PaymentIntentData({required num paymentAmount, required String reference, required List<Article> articles, List<PaymentSource>? paymentSources})

Properties

articles → List<Article>
List of articles to be paid for
final
hashCode → int
The hash code for this object.
no setterinherited
paymentAmount → num
The amount to be paid
final
paymentSources → List<PaymentSource>?
Precise when only want user to pay with specific payment sources
final
reference → String
A unique reference for the payment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited